==> qcad-3.32.3.4-3-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation type="unfinished">縦型/横型</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation type="unfinished">背面</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>カスタム</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>グリッド</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>終端</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>エンティティ</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>垂直</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>タンジェント</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>中心</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>中央</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>交点</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>基準点</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation type="unfinished">距離</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>無効</translation>
    </message>
</context>
</TS>

==> qcad-3.32.5.0-1-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation>垂直/水平</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation>戻る</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>カスタム</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>グリッド</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>終端</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>エンティティ</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>垂直</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>タンジェント</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>中心</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>中央</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>交点</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>基準点</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation>距離</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>無効</translation>
    </message>
</context>
</TS>
